package net.hostsharing.hsadminng.hs.hosting.asset.validators;

import net.hostsharing.hsadminng.hs.hosting.asset.HsHostingAssetEntity;
import net.hostsharing.hsadminng.hs.hosting.asset.HsHostingAssetType;

import java.util.regex.Pattern;

import static net.hostsharing.hsadminng.hs.validation.ArrayProperty.arrayOf;
import static net.hostsharing.hsadminng.hs.validation.BooleanProperty.booleanProperty;
import static net.hostsharing.hsadminng.hs.validation.IntegerProperty.integerProperty;
import static net.hostsharing.hsadminng.hs.validation.StringProperty.stringProperty;

class HsDomainDnsSetupHostingAssetValidator extends HsHostingAssetEntityValidator {

    final static String RR_REGEX =
            "[a-z0-9\\.-]+\\s+" + // a (e.g. domain) name
            "([1-9][0-9]*[HDW]\\s+){0,1}" + // optional TTL
            "IN\\s+" + // record class IN for Internet
            "([1-9][0-9]*[HDW]\\s+){0,1}" + // optional TTL
            "[A-Z]+\\s+([a-z0-9\\.-]+|\"[^\"]*\")\\s*" + // either a simple argument or a more complex in quotes
            "(;.*)*"; // optional comment at the end of the line

    HsDomainDnsSetupHostingAssetValidator() {
        super(  BookingItem.mustBeNull(),
                ParentAsset.mustBeOfType(HsHostingAssetType.DOMAIN_SETUP),
                AssignedToAsset.mustBeNull(),
                AlarmContact.isOptional(),

                integerProperty("TTL").min(0).withDefault(21600),
                booleanProperty("auto-SOA-RR").withDefault(true),
                booleanProperty("auto-NS-RR").withDefault(true),
                booleanProperty("auto-MX-RR").withDefault(true),
                booleanProperty("auto-A+AAAA-RR").withDefault(true),
                booleanProperty("auto-MAILSERVICES-RR").withDefault(true), // incl. AUTOCONFIG_RR, AUTODISCOVER_RR
                booleanProperty("auto-DKIM-RR").withDefault(true),
                booleanProperty("auto-SPF-RR").withDefault(true),
                booleanProperty("auto-WILDCARD-MX-RR").withDefault(true),
                booleanProperty("auto-WILDCARD-A+AAAA-RR").withDefault(true),
                booleanProperty("auto-WILDCARD-DKIM-RR").withDefault(true), // TODO.spec: ask Peter
                booleanProperty("auto-WILDCARD-SPF-RR").withDefault(true),
                arrayOf(
                        stringProperty("user-RR").matchesRegEx(RR_REGEX).required()
                ).optional());
    }

    @Override
    protected Pattern identifierPattern(final HsHostingAssetEntity assetEntity) {
        // FIXME: should be auto-initialized
        return  Pattern.compile("^" + assetEntity.getParentAsset().getIdentifier() + "$");
    }
}
